"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLatestFirefoxVersion = void 0;
const axios_1 = require("axios");
const log = require("loglevel");
const constants_1 = require("../../constants");
const FIREFOX_VERSIONS_URL = 'https://product-details.mozilla.org/1.0/firefox_versions.json';
async function getLatestFirefoxVersion(url = FIREFOX_VERSIONS_URL) {
    try {
        log.debug('Grabbing Firefox version data from', url);
        const response = await axios_1.default.get(url, { timeout: 5000 });
        if (response.status !== 200) {
            throw new Error(`Bad request: Status code ${response.status}`);
        }
        const firefoxVersions = response.data;
        log.debug(`Got latest Firefox version ${firefoxVersions.LATEST_FIREFOX_VERSION}`);
        return firefoxVersions.LATEST_FIREFOX_VERSION;
    }
    catch (err) {
        log.error('getLatestFirefoxVersion ERROR', err);
        log.debug('Falling back to default Firefox version', constants_1.DEFAULT_FIREFOX_VERSION);
        return constants_1.DEFAULT_FIREFOX_VERSION;
    }
}
exports.getLatestFirefoxVersion = getLatestFirefoxVersion;
//# sourceMappingURL=inferFirefoxVersion.js.map